pandaSDMX
=========
.. image:: https://travis-ci.org/dr-leo/pandaSDMX.svg?branch=master
   :target: https://travis-ci.org/dr-leo/pandaSDMX
.. image:: https://codecov.io/gh/dr-leo/pandaSDMX/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/dr-leo/pandaSDMX

| Description: A Python- and pandas-powered client for statistical data and metadata exchange
| Author: Dr. Leo <fhaxbox66@gmail.com>
| License: Apache 2.0
| Documentation: http://pandasdmx.readthedocs.io
| Development website: https://github.com/dr-leo/pandasdmx/
| PyPI: https://pypi.org/project/pandaSDMX/

Purpose of this project
-----------------------

pandaSDMX is SDMX software that facilitates the acquisition and analysis of
SDMX-2.1 compliant data and metadata. These can be rendered in various formats:

- as a hierarchical data structure following closely the SDMX 2.1 information
  model. Technically, the model is a layer on top of the XML or JSON formats rendered
  by SDMX web services.
- as arbitrary output generated by dedicated writers. Currently, there are 
  two writers rendering data sets and structural metadata respectively 
  as pandas Series and DataFrames.

Credits
-------

pandaSDMX originally started as a fork of pysdmx_.

Even if pandaSDMX would not have been possible without the inspiring work done
for that project, the author decided to rewrite it from scratch. Therefore,
pandaSDMX is now an independent project. Many people from all over the world have generously contributed code and feedback 
to this project.  

pandaSDMX ships with a patched version of aadict_, a useful wrapper around the
standard Python dict. It also contains sample data and metadata from the SDMX
user guide.

.. _pysdmx: https://github.com/widukind/pysdmx
.. _aadict: https://github.com/metagriffin/aadict
